<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendarwindow.cpp" line="203"/>
        <source>First Day of Week</source>
        <translation>Πρώτη ημέρα της εβδομάδας</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="40"/>
        <source>Deepin Calendar</source>
        <translation>Ημερολόγιο Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Calendar is a date tool.</source>
        <translation>Εφαρμογή Ημερολογίου </translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="24"/>
        <source>Today</source>
        <translation>Σήμερα</translation>
    </message>
</context>
</TS>